#!/usr/local/bin/bash
#
# Copyright (C) 2004 SIPfoundry Inc.
# Licensed by SIPfoundry under the LGPL license.
#
# Copyright (C) 2004 Pingtel Corp.
# Licensed to SIPfoundry under a Contributor Agreement.

Action=RUN
Status=0
Args=""

while [ $# -ne 0 ]
do
    case ${1} in
        --configtest)
            Action=CONFIGTEST
            ;;

        *)
            Args="$Args $1"
            ;;
    esac           

    shift # always consume 1
done

. /usr/local/libexec/sipx-utils.sh || exit 1

CONFIG_DEFS="/usr/local/etc/sipxpbx/config.defs"

CONFIG_FILES="\
  /usr/local/etc/sipxpbx/registrar-config \
  /usr/local/etc/sipxpbx/mappingrules.xml \
  /usr/local/etc/sipxpbx/fallbackrules.xml \
  "

# If the "config.defs" file exists and the <name>.in file exists for a
# configuration file, then run the config preprocessor to generate the
# fully resolved configuration file.
if [ -f "$CONFIG_DEFS" ]
then
  for i in $CONFIG_FILES ; do
    if [ -f "${i}.in" ]
    then
       /usr/local/bin/configpp --defs "${CONFIG_DEFS}" --in "${i}.in" --out "$i"
    fi
  done
fi

case ${Action} in
   RUN)
     echo $$ > /var/run/sipxpbx/sipregistrar.pid
     exec /usr/local/bin/sipregistrar $Args
     ;;

   CONFIGTEST)
     # check validity of xml routing rules
     /usr/local/bin/sipx-validate-xml /usr/local/etc/sipxpbx/mappingrules.xml
     Status=$(($Status+$?))
     /usr/local/bin/sipx-validate-xml /usr/local/etc/sipxpbx/fallbackrules.xml
     Status=$(($Status+$?))
     ! test -e /var/sipxdata/sipdb/huntgroup.xml \
     || /usr/local/bin/sipx-validate-xml /var/sipxdata/sipdb/huntgroup.xml
     Status=$(($Status+$?))
     ! test -e /var/sipxdata/sipdb/alias.xml \
     || /usr/local/bin/sipx-validate-xml /var/sipxdata/sipdb/alias.xml
     Status=$(($Status+$?))
     ! test -e /var/sipxdata/sipdb/caller-alias.xml \
     || /usr/local/bin/sipx-validate-xml /var/sipxdata/sipdb/caller-alias.xml
     Status=$(($Status+$?))

     # if this system is configured for HA, check that both have valid routes
     SyncWith=`sipx_config_value /usr/local/etc/sipxpbx/registrar-config SIP_REGISTRAR_SYNC_WITH`
     if [ -n "$SyncWith" ]
     then
         myRegDomain=`sipx_config_value /usr/local/etc/sipxpbx/registrar-config SIP_REGISTRAR_DOMAIN_NAME`
         myHostName=`sipx_config_value /usr/local/etc/sipxpbx/registrar-config SIP_REGISTRAR_NAME`
         if [ "$myRegDomain" = "$myHostName" ]
         then
             cat <<EOF
    In redundant configuration, SIP_REGISTRAR_NAME ($myHostName)
               should not equal SIP_REGISTRAR_DOMAIN_NAME ($(myRegDomain)
EOF
             Status=$(($Status+1))
         fi
         for h in ${SyncWith}
         do
           if ! sip_resolves_to $myRegDomain $h 
           then
               cat <<EOF
    Warning: SIP Domain '$myRegDomain' does not resolve to registrar host '$h'
             This is ok only if the proxy on $h is configured to forward to the 
             correct set of registrars.  The recommended configuration is to always
             run a registrar on each host that runs a proxy.
EOF
               Status=1
           fi
         done
     fi
     
     # Check that the log file is writable.
     logfile="/var/log/sipxpbx/sipregistrar.log"
     if [ -e $logfile -a ! -w $logfile ]
     then
         echo "Log file '$logfile' exists but is not writable by user 'sipx'." >&2
         Status=1
     fi
     ;;

esac

exit $Status

